==> fet-5.14.2.tar.bz2: fet-5.14.2/src/interface/modifyconstraintteachersmaxbuildingchangesperweekform.h <==
/***************************************************************************
                          modifyconstraintteachersmaxbuildingchangesperweekform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTTEACHERSMAXBUILDINGCHANGESPERWEEKFORM_H
#define MODIFYCONSTRAINTTEACHERSMAXBUILDINGCHANGESPERWEEKFORM_H

#include "ui_modifyconstraintteachersmaxbuildingchangesperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ModifyConstraintTeachersMaxBuildingChangesPerWeekForm : public QDialog, Ui::ModifyConstraintTeachersMaxBuildingChangesPerWeekForm_template  {
	Q_OBJECT
public:
	ConstraintTeachersMaxBuildingChangesPerWeek* _ctr;

	ModifyConstraintTeachersMaxBuildingChangesPerWeekForm(ConstraintTeachersMaxBuildingChangesPerWeek* ctr);
	~ModifyConstraintTeachersMaxBuildingChangesPerWeekForm();

public slots:
	void constraintChanged();
	void ok();
	void cancel();
};

#endif

==> fet_5.38.1.orig.tar.bz2: fet-5.38.1/src/interface/modifyconstraintteachersmaxbuildingchangesperweekform.h <==
/***************************************************************************
                          modifyconstraintteachersmaxbuildingchangesperweekform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTTEACHERSMAXBUILDINGCHANGESPERWEEKFORM_H
#define MODIFYCONSTRAINTTEACHERSMAXBUILDINGCHANGESPERWEEKFORM_H

#include "ui_modifyconstraintteachersmaxbuildingchangesperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ModifyConstraintTeachersMaxBuildingChangesPerWeekForm : public QDialog, Ui::ModifyConstraintTeachersMaxBuildingChangesPerWeekForm_template  {
	Q_OBJECT
public:
	ConstraintTeachersMaxBuildingChangesPerWeek* _ctr;

	ModifyConstraintTeachersMaxBuildingChangesPerWeekForm(QWidget* parent, ConstraintTeachersMaxBuildingChangesPerWeek* ctr);
	~ModifyConstraintTeachersMaxBuildingChangesPerWeekForm();

public slots:
	void constraintChanged();
	void ok();
	void cancel();
};

#endif
